package ru.amse.baltijsky.javascheme.importer.test;

import ru.amse.baltijsky.javascheme.tree.NodeType;
import ru.amse.baltijsky.javascheme.tree.SchemaNode;

/**
 * Tools for creating test schema trees.
 */
class TestImporterTools {
    /**
     * The test code assigned to all schema nodes.
     */
    public final static String[] TEST_CODE = new String[]{"test"};

    /**
     * Creates a new node of the specified type with the specified code attached that can be accessed from the
     * previously constructed node <code>prev</code> via the "child" link.
     * In the terms of the loadTree tree, it lies one level deeper than the previous node.
     *
     * @param type the type of the node to be constructed
     * @param p    the previous node
     * @param s    the code that is associated with the node
     * @return the created node
     */
    public static SchemaNode createNodeDeeperLevel(NodeType type, SchemaNode p, String[] s) {
        SchemaNode ret = SchemaNode.createNode(type, p, null, s);
        p.addChild(ret);
        return ret;
    }

    /**
     * Creates a new node of the specified type with the specified code attached that can be accessed from the
     * previously constructed node <code>prev</code> via the "next" link.
     * In the terms of the loadTree tree, it lies in the same level that of the previous node.
     *
     * @param type the type of the node to be constructed
     * @param prev the previous node
     * @param s    the code that is associated with the node
     * @return the created node
     */
    public static SchemaNode createNodeSameLevel(NodeType type, SchemaNode prev, String[] s) {
        return SchemaNode.createNode(type, prev.getParent(), prev, s);
    }

    /**
     * Creates a new node of the specified type with the specified code attached that is the "next" node for a
     * parent of the previous node; previous node lies the specified number of levels deeper than the constructed node.
     * It is shallower the specified amount of levels than the previous node in the terms of the loadTree tree.
     *
     * @param depth the depth that should be wound back
     * @param type  the type of the node to be constructed
     * @param prev  the previous node
     * @param s     the code that is associated with the node
     * @return the created node
     */
    public static SchemaNode createNodeShallowerLevel(int depth, NodeType type, SchemaNode prev, String[] s) {
        SchemaNode p = prev;
        for (int i = 0; i < depth; ++i) {
            p = p.getParent();
        }
        return createNodeSameLevel(type, p, s);
    }
}
