package ru.amse.baltijsky.javascheme.tree;

import ru.amse.baltijsky.javascheme.nodeshape.ActionNodeShape;
import ru.amse.baltijsky.javascheme.nodeshape.INodeShape;

/**
 * Represents an atomic action (effectively, bunch of expressions) without any program flow control inside.
 *
 * @todo consider function calls and create a separate node class.
 */
public class ActionNode extends SchemaNode {
    /**
     * Default constructor. Creates a node without previous or parent (nesting) node.
     */
    public ActionNode() {
        super();
    }

    public ActionNode(SchemaNode parentNode, SchemaNode prevNode) {
        super(parentNode, prevNode);
    }

    /**
     * Constructs a new node without previous or nesting node and with information about the corresponding code.
     *
     * @param s code associated with the node
     */
    public ActionNode(String[] s) {
        super(s);
    }

    /**
     * Constructs a new node with full information about the nesting and previous nodes and the corresponding code.
     *
     * @param parentNode link to the parent (nesting) node
     * @param prevNode   link to the node that is previous in the sense of program flow
     * @param s          code associated with the node
     */
    public ActionNode(SchemaNode parentNode, SchemaNode prevNode, String[] s) {
        super(parentNode, prevNode, s);
    }

    public INodeShape getShape() {
        return new ActionNodeShape(getCodeAsString());
    }

    public NodeType getNodeType() {
        return NodeType.ACTION;
    }
}
