package ru.amse.baltijsky.javascheme.tree;

import ru.amse.baltijsky.javascheme.nodeshape.INodeShape;
import ru.amse.baltijsky.javascheme.nodeshape.NoShape;

/**
 * Represents a united bunch of statements marked up in the initial code via special JavaScheme tags.
 * May have several previous nodes (join) and one or zero next nodes (zero iff it is the last node in current nesting scope).
 */
public class UnitBlockNode extends NestingNode {
    /**
     * Default constructor. Creates a node without previous or parent (nesting) node
     * without information about the corresponding code.
     */
    public UnitBlockNode() {
        super();
    }

    public UnitBlockNode(SchemaNode parentNode, SchemaNode prevNode) {
        super(parentNode, prevNode);
    }

    /**
     * Constructs a new node without previous or nesting node and with information about the corresponding code.
     *
     * @param s code associated with the node
     */
    public UnitBlockNode(String[] s) {
        super(s);
    }

    /**
     * Constructs a new node with full information about the nesting and previous nodes and the corresponding code.
     *
     * @param parentNode link to the parent (nesting) node
     * @param prevNode   link to the node that is previous in the sense of program flow
     * @param s          code associated with the node
     */
    public UnitBlockNode(SchemaNode parentNode, SchemaNode prevNode, String[] s) {
        super(parentNode, prevNode, s);
    }

    public INodeShape getShape() {
        return new NoShape("");
    }

    public NodeType getNodeType() {
        return NodeType.UNIT_BLOCK;
    }
}
